==> ars_nouveau-1.19.2-3.13.4.477-sources.jar: com/hollingsworth/arsnouveau/common/capability/FamiliarData.java <==
package com.hollingsworth.arsnouveau.common.capability;

import com.hollingsworth.arsnouveau.ArsNouveau;
import com.hollingsworth.arsnouveau.api.ArsNouveauAPI;
import com.hollingsworth.arsnouveau.api.familiar.AbstractFamiliarHolder;
import com.hollingsworth.arsnouveau.api.familiar.IFamiliar;
import com.hollingsworth.arsnouveau.common.lib.LibEntityNames;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.level.Level;


public class FamiliarData {
    public static final String ENTITY_TAG = "entityTag";
    public static final String FAMILIAR_ID = "familiarID";
    public AbstractFamiliarHolder familiarHolder;
    public CompoundTag entityTag;

    public FamiliarData(ResourceLocation entityID) {
        this.familiarHolder = ArsNouveauAPI.getInstance().getFamiliarHolderMap().get(entityID);
        this.entityTag = new CompoundTag();
    }

    public FamiliarData(CompoundTag tag) {
        this.entityTag = tag.contains(ENTITY_TAG) ? tag.getCompound(ENTITY_TAG) : new CompoundTag();
        this.familiarHolder = ArsNouveauAPI.getInstance().getFamiliarHolderMap().getOrDefault(new ResourceLocation(tag.getString(FAMILIAR_ID)),
                ArsNouveauAPI.getInstance().getFamiliarHolderMap().get(new ResourceLocation(ArsNouveau.MODID, LibEntityNames.FAMILIAR_WIXIE)));
    }

    public CompoundTag toTag() {
        CompoundTag tag = new CompoundTag();
        tag.putString(FAMILIAR_ID, familiarHolder.getRegistryName().toString());
        tag.put(ENTITY_TAG, entityTag);
        return tag;
    }

    public IFamiliar getEntity(Level level) {
        IFamiliar familiar = familiarHolder.getSummonEntity(level, entityTag);
        familiar.setHolderID(familiarHolder.getRegistryName());
        return familiar;
    }
}

==> ars_nouveau-1.21.1-5.8.3.1112-sources.jar: com/hollingsworth/arsnouveau/common/capability/FamiliarData.java <==
package com.hollingsworth.arsnouveau.common.capability;

import com.hollingsworth.arsnouveau.ArsNouveau;
import com.hollingsworth.arsnouveau.api.familiar.AbstractFamiliarHolder;
import com.hollingsworth.arsnouveau.api.familiar.IFamiliar;
import com.hollingsworth.arsnouveau.api.registry.FamiliarRegistry;
import com.hollingsworth.arsnouveau.common.lib.LibEntityNames;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.level.Level;


public class FamiliarData {
    public static final String ENTITY_TAG = "entityTag";
    public static final String FAMILIAR_ID = "familiarID";
    public AbstractFamiliarHolder familiarHolder;
    public CompoundTag entityTag;

    public FamiliarData(ResourceLocation entityID) {
        this.familiarHolder = FamiliarRegistry.getFamiliarHolderMap().get(entityID);
        this.entityTag = new CompoundTag();
    }

    public FamiliarData(CompoundTag tag) {
        this.entityTag = tag.contains(ENTITY_TAG) ? tag.getCompound(ENTITY_TAG) : new CompoundTag();
        this.familiarHolder = FamiliarRegistry.getFamiliarHolderMap().getOrDefault(ResourceLocation.tryParse(tag.getString(FAMILIAR_ID)),
                FamiliarRegistry.getFamiliarHolderMap().get(ArsNouveau.prefix( LibEntityNames.FAMILIAR_WIXIE)));
    }

    public CompoundTag toTag() {
        CompoundTag tag = new CompoundTag();
        tag.putString(FAMILIAR_ID, familiarHolder.getRegistryName().toString());
        tag.put(ENTITY_TAG, entityTag);
        return tag;
    }

    public IFamiliar getEntity(Level level) {
        IFamiliar familiar = familiarHolder.getSummonEntity(level, entityTag);
        familiar.setHolderID(familiarHolder.getRegistryName());
        return familiar;
    }
}
